Improve this doc

# Error: $parse:syntax
Syntax Error

    Syntax Error: Token '{0}' {1} at column {2} of the expression [{3}] starting at [{4}].

## Description

Occurs when there is a syntax error in an expression. These errors are thrown while compiling the expression. The error message contains a more precise description of the error, including the location (column) in the expression where the error occurred.

To resolve, learn more about Angular expressions, identify the error and fix the expression's syntax.